@@ -8,8 +8,8 @@ PUBLISH_TO_ELASTIC = os.environ.get("PUBLISH_TO_ELASTIC", True)
 ELASTICSEARCH_HOST = os.environ.get(
     "ELASTICSEARCH_HOST", "https:localhost:9200/")
 ENVIRONMENT = os.environ.get("ENVIRONMENT", "dev")
-CLIENT = os.environ.get("CLIENT", "xyz")
-ROBOT_NAME = os.environ.get("ROBOT_NAME", "Google")
+CLIENT = os.environ.get("CLIENT", "clientename")
+ROBOT_NAME = os.environ.get("ROBOT_NAME", "roboname")
 
 
 # TODO Exemplo de classe para conexão com o Elastic
