@@ -23,19 +23,19 @@ class LogToDriver:
     def log_info(self, message, traceId=None, **kwargs):
         msg = self._message(message, traceId=traceId, **kwargs)
         logger.info(msg, html=True, also_console=True)
-        self.el.publish(message, traceId=traceId, **kwargs)
+        self.el.publish(message, traceId=traceId, level="INFO", **kwargs)
 
     def log_warn(self, message, traceId=None, **kwargs):
         msg = self._message(message, traceId=traceId, **kwargs)
         logger.warn(msg, html=True)
-        self.el.publish(message, traceId=traceId, **kwargs)
+        self.el.publish(message, traceId=traceId, level="WARN", **kwargs)
 
     def log_debug(self, message, traceId=None, **kwargs):
         msg = self._message(message, traceId=traceId, **kwargs)
         logger.debug(msg, html=True)
-        self.el.publish(message, traceId=traceId, **kwargs)
+        self.el.publish(message, traceId=traceId, level="DEBUG", **kwargs)
 
     def log_error(self, message, traceId=None, **kwargs):
         msg = self._message(message, traceId=traceId, **kwargs)
         logger.error(msg, html=True)
-        self.el.publish(message, traceId=traceId, **kwargs)
+        self.el.publish(message, traceId=traceId, level="ERROR", **kwargs)
